@@ -3,6 +3,9 @@ from os import linesep
 from io import StringIO
 from datetime import datetime
 import pandas as pd
+from unswamp.checks import (
+    Functions,
+)
 
 from random import seed, random, randint, choice, SystemRandom
 
