@@ -2,7 +2,7 @@ from sys import path
 path.append('../unswamp/')
 
 from helpers import TestHelpers
-from unswamp.checks import (
+from unswamp.checks.column import (
     CheckColumnAllSame,
 )
 from unittest import TestCase, main
