@@ -2,10 +2,10 @@ from sys import path
 path.append('../unswamp/')
 
 from helpers import TestHelpers
-from unswamp.checks import (
+from unswamp.checks.column import (
     CheckColumnFunctionAll,
-    Functions,
 )
+from unswamp.checks import Functions
 from unittest import TestCase, main
 
 
@@ -15,20 +15,19 @@ class TestCheckColumnFunctionAll(TestCase):
         col = TestHelpers.str_random()
         val = TestHelpers.str_random()
         # TODO: use mock
-        func = TestHelpers.function_name
-        check = CheckColumnFunctionAll(check_id, col, val, func)
+        func_name = TestHelpers.function_name
+        check = CheckColumnFunctionAll(check_id, col, val, func_name)
 
         TestHelpers.test_property(self, check, "id", check_id)
         TestHelpers.test_property(self, check, "column_name", col)
         TestHelpers.test_property(self, check, "column_value", val)
-        TestHelpers.test_property(self, check, "column_function_name", func)
 
     def test_CheckColumnFunctionAll_run(self):
         check_id = TestHelpers.str_random()
         col = "Col_Same"
         val = TestHelpers.same
-        func = "check_column_equal"
-        check = CheckColumnFunctionAll(check_id, col, val, func)
+        func_name = TestHelpers.function_name
+        check = CheckColumnFunctionAll(check_id, col, val, func_name)
         dataset = TestHelpers.get_dataset()
         result = check.run(dataset)
         self.assertTrue(
