@@ -2,7 +2,7 @@ from sys import path
 path.append('../unswamp/')
 
 from unittest import TestCase, main
-from unswamp.checks import (
+from unswamp.checks.column import (
     CheckColumnLikeAll,
 )
 from helpers import TestHelpers
@@ -17,7 +17,7 @@ class TestCheckColumnLikeAll(TestCase):
 
         TestHelpers.test_property(self, check, "id", check_id)
         TestHelpers.test_property(self, check, "column_name", col)
-        TestHelpers.test_property(self, check, "column_like", like)
+        TestHelpers.test_property(self, check, "like", like)
 
     def test_CheckColumnLikeAll_run(self):
         check_id = TestHelpers.str_random()
