@@ -2,7 +2,7 @@ from sys import path
 path.append('../unswamp/')
 
 from unittest import TestCase, main
-from unswamp.checks import (
+from unswamp.checks.column import (
     CheckColumnIsUnique,
 )
 from helpers import TestHelpers
