@@ -2,7 +2,7 @@ from sys import path
 path.append('../unswamp/')
 
 from unittest import TestCase, main
-from unswamp.checks import (
+from unswamp.checks.column import (
     CheckColumnRegexAll,
 )
 from helpers import TestHelpers
@@ -17,7 +17,7 @@ class TestCheckColumnRegexAll(TestCase):
 
         TestHelpers.test_property(self, check, "id", check_id)
         TestHelpers.test_property(self, check, "column_name", col)
-        TestHelpers.test_property(self, check, "column_regex", regex)
+        TestHelpers.test_property(self, check, "regex", regex)
 
     def test_CheckColumnRegexAll_run(self):
         check_id = TestHelpers.str_random()
