@@ -8,11 +8,5 @@ class BaseColumnCheck():
     ##################################################################################################
     # Properties
     ##################################################################################################
-    @property
-    def column_name(self):
-        return self._column_name
+    column_name = None
 
-    @column_name.setter
-    def column_name(self, value):
-        self._column_name = value
-        self._settings["column_name"] = value
