@@ -8,11 +8,4 @@ class BaseValueCheck():
     ##################################################################################################
     # Properties
     ##################################################################################################
-    @property
-    def column_value(self):
-        return self._column_value
-
-    @column_value.setter
-    def column_value(self, value):
-        self._column_value = value
-        self._settings["column_value"] = value
+    column_value = None
