@@ -7,10 +7,10 @@ class CheckSuite(SerializableObject, MetaDataObject):
     ##################################################################################################
     # Constructor
     ##################################################################################################
-    def __init__(self, name, checks=None, meta_data=None):
+    def __init__(self, suite_id, checks=None, meta_data=None):
         SerializableObject.__init__(self)
         MetaDataObject.__init__(self, meta_data)
-        self.name = name
+        self.id = suite_id
         if checks is None:
             checks = []
         self.checks = checks
@@ -21,30 +21,13 @@ class CheckSuite(SerializableObject, MetaDataObject):
     def add_check(self, check):
         self.checks.append(check)
 
-    def run(self, dataset):
-        run = CheckRun()
-        run.run(dataset, self.checks)
+    def run(self, dataset, run_id=None):
+        run = CheckRun(run_id)
+        run.run(dataset, self)
         return run
 
     ##################################################################################################
     # Properties
     ##################################################################################################
-    @property
-    def version(self):
-        return self._version
-
-    @property
-    def name(self):
-        return self._name
-
-    @name.setter
-    def name(self, value):
-        self._name = value
-
-    @property
-    def checks(self):
-        return self._checks
-
-    @checks.setter
-    def checks(self, value):
-        self._checks = value
+    id = None
+    checks = []
